@@ -30,11 +30,12 @@ def ns_read_size(input):
 def ns_reads(input):
     size = ns_read_size(input)
     data = ""
-    while len(data) < size:
+    while size > 0:
         s = input.read(size)
         if not s:
             raise IOError, 'short netstring read'
         data = data + s
+        size -= len(s)
     if input.read(1) != ',':
         raise IOError, 'missing netstring terminator'
     return data
@@ -56,9 +57,9 @@ class SCGIHandler:
                 # parent probably exited  (EPIPE comes thru as OSError)
                 raise SystemExit
             conn = socket.fromfd(fd, socket.AF_INET, socket.SOCK_STREAM)
-            # Make sure the socket is blocking.  Appearently, on FreeBSD the
-            # socket non-blocking.  I think that's an OS bug but I don't have
-            # the resources to track it down.
+            # Make sure the socket is blocking.  Apparently, on FreeBSD the
+            # socket is non-blocking.  I think that's an OS bug but I don't
+            # have the resources to track it down.
             conn.setblocking(1)
             os.close(fd)
             self.handle_connection(conn)
